Slice Extension types (SliceStack, Slice, Polygon, etc.).
Structs
- Polygon
- A closed polygon contour within a slice, defined by a sequence of segments.
- Segment
- A single segment within a polygon contour.
- Slice
- A single 2D slice at a specific Z height.
- Slice
Ref - A reference to a slice stack in an external model part.
- Slice
Stack - A stack of 2D slices defining a geometry (Slice Extension).
- Vertex2D
- A 2D vertex with X and Y coordinates.