pub struct AssemblyItem {
pub object_id: u32,
pub instance_count: u32,
pub transform: Option<String>,
pub offset: Option<String>,
}Expand description
An assembly item from a Bambu Studio project file.
Fields
object_id: u32Object resource ID.
instance_count: u32Number of instances of this object in the assembly.
transform: Option<String>Transform matrix string.
offset: Option<String>Offset string.