pub fn get_attribute_uuid(e: &BytesStart<'_>) -> Result<Option<Uuid>>Expand description
Returns the uuid or p:uuid attribute parsed as a Uuid, or None if absent.
pub fn get_attribute_uuid(e: &BytesStart<'_>) -> Result<Option<Uuid>>Returns the uuid or p:uuid attribute parsed as a Uuid, or None if absent.