Module diff

Module diff 

Model diff utilities for comparing two 3MF models.

Structs

MetadataDiff
A difference in a single metadata key between two models.
ModelDiff
The computed diff between two 3MF models.

Enums

BuildDiff
A difference in the build item list between two models.
ResourceDiff
A difference in a resource between two models.

Functions

compare_models
Compares two 3MF models and returns a ModelDiff describing the differences.