Module hardware

Module hardware 

Hardware capability detection (CPU architecture, SIMD features).

Structs

HardwareCapabilities
Hardware capabilities of the current system, used for informational statistics.

Functions

detect_capabilities
Detects and returns the hardware capabilities of the current system.