pub fn detect_capabilities() -> HardwareCapabilitiesExpand description
Detects and returns the hardware capabilities of the current system.
pub fn detect_capabilities() -> HardwareCapabilitiesDetects and returns the hardware capabilities of the current system.