pub fn validate_geometry(
model: &Model,
level: ValidationLevel,
report: &mut ValidationReport,
)Expand description
Validates the geometry of all mesh objects in the model at the given validation level.
pub fn validate_geometry(
model: &Model,
level: ValidationLevel,
report: &mut ValidationReport,
)Validates the geometry of all mesh objects in the model at the given validation level.