pub fn validate_schema(_model: &Model, _report: &mut ValidationReport)Expand description
Performs basic schema checks not caught by the XML parser.
pub fn validate_schema(_model: &Model, _report: &mut ValidationReport)Performs basic schema checks not caught by the XML parser.