Hardware capability detection (CPU architecture, SIMD features).
Structs
- Hardware
Capabilities - Hardware capabilities of the current system, used for informational statistics.
Functions
- detect_
capabilities - Detects and returns the hardware capabilities of the current system.